@@ -114,10 +114,10 @@ m.register 'initialize' {
 
         if params.workspaceFolders then
             for _, folder in ipairs(params.workspaceFolders) do
-                workspace.create(folder.uri)
+                workspace.create(files.getRealUri(folder.uri))
             end
         elseif params.rootUri then
-            workspace.create(params.rootUri)
+            workspace.create(files.getRealUri(params.rootUri))
         end
 
         local response = {
@@ -249,12 +249,14 @@ m.register 'workspace/didChangeWorkspaceFolders' {
     function (params)
         log.debug('workspace/didChangeWorkspaceFolders', inspect(params))
         for _, folder in ipairs(params.event.added) do
-            workspace.create(folder.uri)
+            local uri = files.getRealUri(folder.uri)
+            workspace.create(uri)
             m.updateConfig()
-            workspace.reload(scope.getScope(folder.uri))
+            workspace.reload(scope.getScope(uri))
         end
         for _, folder in ipairs(params.event.removed) do
-            workspace.remove(folder.uri)
+            local uri = files.getRealUri(folder.uri)
+            workspace.remove(uri)
         end
     end
 }
@@ -263,12 +265,7 @@ m.register 'textDocument/didOpen' {
     ---@async
     function (params)
         local doc      = params.textDocument
-        local scheme   = furi.split(doc.uri)
-        local supports = config.get(doc.uri, 'Lua.workspace.supportScheme')
-        if not util.arrayHas(supports, scheme) then
-            return
-        end
-        local uri    = files.getRealUri(doc.uri)
+        local uri      = files.getRealUri(doc.uri)
         log.debug('didOpen', uri)
         local text  = doc.text
         files.setText(uri, text, true, function (file)
@@ -295,18 +292,13 @@ m.register 'textDocument/didClose' {
 m.register 'textDocument/didChange' {
     ---@async
     function (params)
-        local doc      = params.textDocument
-        local scheme   = furi.split(doc.uri)
-        local supports = config.get(doc.uri, 'Lua.workspace.supportScheme')
-        if not util.arrayHas(supports, scheme) then
-            return
-        end
+        local doc     = params.textDocument
         local changes = params.contentChanges
         local uri     = files.getRealUri(doc.uri)
-        workspace.awaitReady(uri)
-        local text = files.getOriginText(uri)
+        local text    = files.getOriginText(uri)
         if not text then
-            files.setText(uri, pub.awaitTask('loadFile', furi.decode(uri)), false)
+            text = util.loadFile(furi.decode(uri))
+            files.setText(uri, text, false)
             return
         end
         local rows = files.getCachedRows(uri)
@@ -605,19 +597,7 @@ m.register 'textDocument/completion' {
     function (params)
         local uri  = files.getRealUri(params.textDocument.uri)
         if not workspace.isReady(uri) then
-            local count, max = workspace.getLoadingProcess(uri)
-            return {
-                {
-                    label = lang.script('HOVER_WS_LOADING', count, max),
-                    textEdit    = {
-                        range   = {
-                            start   = params.position,
-                            ['end'] = params.position,
-                        },
-                        newText = '',
-                    },
-                }
-            }
+            return nil
         end
         local _ <close> = progress.create(uri, lang.script.WINDOW_PROCESSING_COMPLETION, 0.5)
         --log.info(util.dump(params))
@@ -792,8 +772,8 @@ m.register 'textDocument/signatureHelp' {
             for j, param in ipairs(result.params) do
                 parameters[j] = {
                     label = {
-                        param.label[1],
-                        param.label[2],
+                        converter.len(result.label, 1, param.label[1]),
+                        converter.len(result.label, 1, param.label[2]),
                     }
                 }
             end
@@ -924,7 +904,7 @@ m.register 'textDocument/codeLens' {
             resolveProvider = true,
         }
     },
-    abortByFileUpdate = true,
+    --abortByFileUpdate = true,
     ---@async
     function (params)
         local uri = files.getRealUri(params.textDocument.uri)
@@ -973,6 +953,7 @@ m.register 'workspace/executeCommand' {
                 'lua.solve',
                 'lua.jsonToLua',
                 'lua.setConfig',
+                'lua.getConfig',
                 'lua.autoRequire',
             },
         },
@@ -992,9 +973,20 @@ m.register 'workspace/executeCommand' {
         elseif command == 'lua.setConfig' then
             local core = require 'core.command.setConfig'
             return core(params.arguments)
+        elseif command == 'lua.getConfig' then
+            local core = require 'core.command.getConfig'
+            return core(params.arguments)
         elseif command == 'lua.autoRequire' then
             local core = require 'core.command.autoRequire'
             return core(params.arguments[1])
+        elseif command == 'lua.exportDocument' then
+            local core = require 'core.command.exportDocument'
+            core(params.arguments)
+        elseif command == 'lua.reloadFFIMeta' then
+            local core = require 'core.command.reloadFFIMeta'
+            for _, scp in ipairs(workspace.folders) do
+                core(scp.uri)
+            end
         end
     end
 }
@@ -1424,8 +1416,8 @@ m.register 'textDocument/inlayHint' {
                 },
                 position     = converter.packPosition(state, res.offset),
                 kind         = res.kind,
-                paddingLeft  = true,
-                paddingRight = true,
+                paddingLeft  = res.kind == 1,
+                paddingRight = res.kind == 2,
             }
         end
         return hintResults
